@@ -59,7 +59,8 @@ import platform
 # float is always defined as 32 bits
 # double is defined as 64 bits
 from ctypes import byref, POINTER, create_string_buffer, c_float, \
-    c_int16, c_uint16, c_int32, c_uint32, c_uint64, c_void_p, c_int8
+    c_int16, c_uint16, c_int32, c_uint32, c_uint64, c_void_p, c_int8, \
+    CFUNCTYPE
 from ctypes import c_int32 as c_enum
 
 import warnings
@@ -67,6 +68,52 @@ import warnings
 from picoscope.picobase import _PicoscopeBase
 
 
+# Decorators for callback functions. PICO_STATUS is uint32_t.
+def blockReady(function):
+    """typedef void (*ps4000aBlockReady)
+    (
+     int16_t         handle,
+     PICO_STATUS     status,
+     void          * pParameter
+    )
+    """
+    callback = CFUNCTYPE(c_void_p, c_int16, c_uint32, c_void_p)
+    return callback(function)
+
+
+def dataReady(function):
+    """typedef void (*ps4000aDataReady)
+    (
+     int16_t         handle,
+     PICO_STATUS     status,
+     uint32_t        noOfSamples,
+     int16_t         overflow,
+     void         * pParameter
+    )
+    """
+    callback = CFUNCTYPE(c_void_p,
+                         c_int16, c_uint32, c_uint32, c_int16, c_void_p)
+    return callback(function)
+
+
+def streamingReady(function):
+    """typedef void (*ps4000aStreamingReady)
+    (
+        int16_t     handle,
+        int32_t     noOfSamples,
+        uint32_t    startIndex,
+        int16_t     overflow,
+        uint32_t    triggerAt,
+        int16_t     triggered,
+        int16_t     autoStop,
+        void      * pParameter
+    )
+    """
+    callback = CFUNCTYPE(c_void_p, c_int16, c_int32, c_uint32, c_int16,
+                         c_uint32, c_int16, c_int16, c_void_p)
+    return callback(function)
+
+
 class PS4000a(_PicoscopeBase):
     """The following are low-level functions for the PS4000A."""
 
@@ -281,13 +328,17 @@ class PS4000a(_PicoscopeBase):
         self.checkResult(m)
 
     def _lowLevelRunBlock(self, numPreTrigSamples, numPostTrigSamples,
-                          timebase, oversample, segmentIndex):
+                          timebase, oversample, segmentIndex, callback,
+                          pParameter):
+        # Hold a reference to the callback so that the Python
+        # function pointer doesn't get free'd
+        self._c_runBlock_callback = blockReady(callback)
         timeIndisposedMs = c_int32()
         m = self.lib.ps4000aRunBlock(
             c_int16(self.handle), c_int32(numPreTrigSamples),
             c_int32(numPostTrigSamples), c_uint32(timebase),
-            byref(timeIndisposedMs),
-            c_uint32(segmentIndex), c_void_p(), c_void_p())
+            byref(timeIndisposedMs), c_uint32(segmentIndex),
+            self._c_runBlock_callback, c_void_p())
         self.checkResult(m)
         return timeIndisposedMs.value
 
@@ -310,7 +361,7 @@ class PS4000a(_PicoscopeBase):
         noSamples
             Number of required samples.
         oversample
-        Nnot used.
+            Not used.
         segmentIndex
             Index of the segment to save samples in
 
