@@ -56,12 +56,25 @@ import platform
 # float is always defined as 32 bits
 # double is defined as 64 bits
 from ctypes import byref, POINTER, create_string_buffer, c_float, \
-    c_int16, c_int32, c_uint32, c_void_p, c_int64
+    c_int16, c_int32, c_uint32, c_void_p, c_int64, CFUNCTYPE
 from ctypes import c_int32 as c_enum
 
 from picoscope.picobase import _PicoscopeBase
 
 
+# Decorators for callback functions. PICO_STATUS is uint32_t.
+def blockReady(function):
+    """typedef void (*ps5000aBlockReady)
+    (
+     int16_t         handle,
+     PICO_STATUS     status,
+     void          * pParameter
+    )
+    """
+    callback = CFUNCTYPE(c_void_p, c_int16, c_uint32, c_void_p)
+    return callback(function)
+
+
 class PS5000a(_PicoscopeBase):
     """The following are low-level functions for the PS5000."""
 
@@ -274,14 +287,17 @@ class PS5000a(_PicoscopeBase):
         self.checkResult(m)
 
     def _lowLevelRunBlock(self, numPreTrigSamples, numPostTrigSamples,
-                          timebase, oversample, segmentIndex):
-        # Oversample is NOT used!
+                          timebase, oversample, segmentIndex, callback,
+                          pParameter):
+        # Hold a reference to the callback so that the Python
+        # function pointer doesn't get free'd.
+        self._c_runBlock_callback = blockReady(callback)
         timeIndisposedMs = c_int32()
         m = self.lib.ps5000aRunBlock(
             c_int16(self.handle), c_uint32(numPreTrigSamples),
             c_uint32(numPostTrigSamples), c_uint32(timebase),
             byref(timeIndisposedMs), c_uint32(segmentIndex),
-            c_void_p(), c_void_p())
+            self._c_runBlock_callback, c_void_p())
         self.checkResult(m)
         return timeIndisposedMs.value
 
