@@ -268,13 +268,16 @@ class PS6000(_PicoscopeBase):
         self.checkResult(m)
 
     def _lowLevelRunBlock(self, numPreTrigSamples, numPostTrigSamples,
-                          timebase, oversample, segmentIndex):
+                          timebase, oversample, segmentIndex, callback,
+                          pParameter):
         timeIndisposedMs = c_int32()
         m = self.lib.ps6000RunBlock(
             c_int16(self.handle), c_uint32(numPreTrigSamples),
             c_uint32(numPostTrigSamples), c_uint32(timebase),
             c_int16(oversample), byref(timeIndisposedMs),
             c_uint32(segmentIndex), c_void_p(), c_void_p())
+        # According to the documentation, 'callback, pParameter' should work
+        # instead of the last two c_void_p parameters.
         self.checkResult(m)
         return timeIndisposedMs.value
 
